@@ -6,7 +6,11 @@ from pydantic import BaseModel, validator, StrictStr, StrictBool, StrictInt, Str
 
 from .. import api
 
-__all__ = ["ModelExecution", "get_default_model_execution", "set_default_model_execution"]
+__all__ = [
+    "ModelExecution",
+    "get_default_model_execution",
+    "set_default_model_execution",
+]
 
 
 # Credentials
@@ -893,7 +897,7 @@ class ModelExecution(BaseModel):
     currentExecutionInstant: datetime
     pythonModelInstance: ModelInstance
 
-    def set_as_default_event(self):
+    def set_as_default_model_execution(self):
         set_default_model_execution(self)
 
     @property
@@ -917,6 +921,9 @@ class ModelExecution(BaseModel):
             "output_parameter_ids": self.pythonModelInstance.get_output_dict(mode="id"),
         }
 
+    def get_execution_argument_value(self, argument_name: str):
+        return self.execution_kwargs[argument_name]
+
 
 # Current event
 DEFAULT_EVENT: Optional[ModelExecution] = None
