@@ -1,5 +1,6 @@
 from typing import Optional, Union
 from datetime import datetime, timedelta, timezone
+import dateutil
 
 from .. import _dtos
 from ... import api
@@ -22,14 +23,22 @@ class TestModelExecution(_dtos.ModelExecution):
                 f"{data_exchange_mode} is not valid for 'data_exchange_mode'"
             )
 
+        # Dates parsing and formatting
+        if isinstance(last_successful_execution_instant, str):
+            last_execution = dateutil.parser.parse(last_successful_execution_instant)
+        else:
+            last_execution = last_successful_execution_instant
+        if isinstance(current_execution_instant, str):
+            current_execution = dateutil.parser.parse(current_execution_instant)
+        else:
+            current_execution = current_execution_instant
+
         # Init
         super().__init__(
             testMode=test_mode,
             credentials=None,
-            lastSuccessfulExecutionInstant=last_successful_execution_instant.astimezone(
-                timezone.utc
-            ),
-            currentExecutionInstant=current_execution_instant.astimezone(timezone.utc),
+            lastSuccessfulExecutionInstant=last_execution.astimezone(timezone.utc),
+            currentExecutionInstant=current_execution.astimezone(timezone.utc),
             pythonModelInstance=_dtos.ModelInstance(
                 id="test_instance_id",
                 trigger=_dtos.CronTrigger(type="cron-trigger", cron="0 0 * * * *"),
@@ -54,9 +63,6 @@ class TestModelExecution(_dtos.ModelExecution):
         test_model_execution.pythonModelInstance = model_execution.pythonModelInstance
         return test_model_execution
 
-    def get_execution_argument_value(self, argument_name: str):
-        return self.execution_kwargs[argument_name]
-
     def add_string_input(
         self,
         source_code_name: str = "string_input",
